==> haskell-lifted-async-0.10.2.7-136-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-async
version:              0.10.2.7
visibility:           public
id:                   lifted-async-0.10.2.7-HWv9dv6tA2M9qihTmkNkf0
key:                  lifted-async-0.10.2.7-HWv9dv6tA2M9qihTmkNkf0
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2024 Mitsutoshi Aoe
maintainer:           Mitsutoshi Aoe <me@maoe.name>
author:               Mitsutoshi Aoe
homepage:             https://github.com/maoe/lifted-async
synopsis:
    Run lifted IO operations asynchronously and wait for their results

description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

category:             Concurrency
abi:                  03e14f2086f7f9a0e018d7aa99e624c7
exposed:              True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-async
hs-libraries:         HSlifted-async-0.10.2.7-HWv9dv6tA2M9qihTmkNkf0
depends:
    async-2.2.5-CA4aEq3ECoz7BppWAZygZ1 base-4.17.2.1
    constraints-0.14.2-JWwezbIw6Y84nrFigfYVBo
    lifted-base-0.2.3.12-9AWsxnOFXVsCXHHwQPRlgj
    monad-control-1.0.3.1-JhIUlMwO22REEhKxuYKLpf
    transformers-base-0.4.6-BAx0nW43BWmJb9h46BesnM

haddock-interfaces:
    /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock

haddock-html:         /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-async-0.10.2.7-137-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-async
version:              0.10.2.7
visibility:           public
id:                   lifted-async-0.10.2.7-Cjto9SW6WYX45BZoLvStUT
key:                  lifted-async-0.10.2.7-Cjto9SW6WYX45BZoLvStUT
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2024 Mitsutoshi Aoe
maintainer:           Mitsutoshi Aoe <me@maoe.name>
author:               Mitsutoshi Aoe
homepage:             https://github.com/maoe/lifted-async
synopsis:
    Run lifted IO operations asynchronously and wait for their results

description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

category:             Concurrency
abi:                  5dfa7479579abb256198756a2aa9d0f2
exposed:              True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-async
hs-libraries:         HSlifted-async-0.10.2.7-Cjto9SW6WYX45BZoLvStUT
depends:
    async-2.2.5-IMWOwzxkt69JaaUstRte6Z base-4.17.2.1
    constraints-0.14.2-IZce8BzydSuK5aBBxcAfPE
    lifted-base-0.2.3.12-KQ6N6VbPRf36rRfI7Jema3
    monad-control-1.0.3.1-CJN9kDyKbOMIWFPg47LY0s
    transformers-base-0.4.6-dPDTCGexYtH2DfPCFTe3V

haddock-interfaces:
    /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock

haddock-html:         /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
